# Text

Show a text string in a chosen color. Optionally collect keyboard responses while the text is on screen.

## When To Use

- Present brief instructions, cues, or labels in text form.
- Simple Stroop-style text displays (color/word).
- A lightweight alternative to full HTML when you just need colored text.

## Example: Flanker Task

A central target stimulus is flanked by distractor stimuli. The participant is asked to respond to the direction of the target stimulus while ignoring the distractors.

![Flanker Task](../../img/stimuli/flanker.png)

## Example: Stroop Task

A colored word is displayed. In most variants, the participant is asked to name the color of the word. Here, we show a version where the participnat has to decide weather color and word fit (are congruent) or not (are incongruent).

![Stroop Task](../../img/stimuli/stroop.png)

